| pldamixture-package | R Documentation |
pldamixture implements the "General Framework for Regression with
Mismatched Data" developed by Slawski et al., 2025. The framework uses a
mixture model for pairs of linked records whose two components reflect
distributions conditional on match status, i.e., correct match or mismatch.
Inference is based on composite likelihood and the EM algorithm.
The package contains 4 functions for usage:
fit_mixture
print.fitmixture
summary.fitmixture
predict.fitmixture
The references below discuss the implemented framework in more detail.
*Corresponding Author (mslawski@virginia.edu)
Maintainer: Priyanjali Bukke postlink.group@gmail.com
Authors:
Priyanjali Bukke postlink.group@gmail.com
Zhenbang Wang
Martin Slawski mslawski@virginia.edu (mslawski@virginia.edu)
Brady T. West
Emanuel Ben-David
Guoqing Diao
Slawski, M.*, West, B. T., Bukke, P., Diao, G., Wang, Z., & Ben-David, E. (2025).
A General Framework for Regression with Mismatched Data Based on Mixture Modeling.
Journal of the Royal Statistical Society Series A: Statistics in Society,
188(3), 896-919. < \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2306.00909")} >
Bukke, P., Ben-David, E., Diao, G., Slawski, M.*, & West, B. T. (2025).
Cox Proportional Hazards Regression Using Linked Data: An Approach Based on Mixture Modelling.
Slawski, M.*, Diao, G., Ben-David, E. (2021). A pseudo-likelihood approach to linear regression with partially shuffled data. Journal of Computational and Graphical Statistics. 30(4), 991-1003 < \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2020.1870482")} >
Useful links:
# optional inputs for linear regression of age at death on year of birth,
# using a cubic polynomial specification.
## use commonness of names as predictors of match status
## first and last names were used for linkage
mformula <- ~commf + comml
## hand-linked records are considered "safe" matches
safematches <- ifelse(lifem$hndlnk =="Hand-Linked At Some Level", TRUE, FALSE)
## overall mismatch rate in the data set is assumed to be ~ 0.05
mrate <- 0.05
fit <- fit_mixture(age_at_death ~ poly(unit_yob, 3, raw = TRUE), data = lifem,
family = "gaussian", mformula, safematches, mrate)
print(fit)
summary(fit)
predict(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.